==> zio-aws-batch_2.13-5.17.148.1-sources.jar: zio/aws/batch/model/LogConfiguration.scala <==
package zio.aws.batch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LogConfiguration(
    logDriver: zio.aws.batch.model.LogDriver,
    options: Option[Map[String, String]] = None,
    secretOptions: Option[Iterable[zio.aws.batch.model.Secret]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.LogConfiguration = {
    import LogConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.LogConfiguration
      .builder()
      .logDriver(logDriver.unwrap)
      .optionallyWith(
        options.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.options)
      .optionallyWith(
        secretOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.secretOptions)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.LogConfiguration.ReadOnly =
    zio.aws.batch.model.LogConfiguration.wrap(buildAwsValue())
}
object LogConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.LogConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.LogConfiguration =
      zio.aws.batch.model.LogConfiguration(
        logDriver,
        options.map(value => value),
        secretOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def logDriver: zio.aws.batch.model.LogDriver
    def options: Option[Map[String, String]]
    def secretOptions: Option[List[zio.aws.batch.model.Secret.ReadOnly]]
    def getLogDriver: ZIO[Any, Nothing, zio.aws.batch.model.LogDriver] =
      ZIO.succeed(logDriver)
    def getOptions: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("options", options)
    def getSecretOptions
        : ZIO[Any, AwsError, List[zio.aws.batch.model.Secret.ReadOnly]] =
      AwsError.unwrapOptionField("secretOptions", secretOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.LogConfiguration
  ) extends zio.aws.batch.model.LogConfiguration.ReadOnly {
    override val logDriver: zio.aws.batch.model.LogDriver =
      zio.aws.batch.model.LogDriver.wrap(impl.logDriver())
    override val options: Option[Map[String, String]] = scala
      .Option(impl.options())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val secretOptions
        : Option[List[zio.aws.batch.model.Secret.ReadOnly]] = scala
      .Option(impl.secretOptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.batch.model.Secret.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.LogConfiguration
  ): zio.aws.batch.model.LogConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-batch_2.13-6.20.83.2-sources.jar: zio/aws/batch/model/LogConfiguration.scala <==
package zio.aws.batch.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class LogConfiguration(
    logDriver: zio.aws.batch.model.LogDriver,
    options: Optional[Map[String, String]] = Optional.Absent,
    secretOptions: Optional[Iterable[zio.aws.batch.model.Secret]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.LogConfiguration = {
    import LogConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.LogConfiguration
      .builder()
      .logDriver(logDriver.unwrap)
      .optionallyWith(
        options.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.options)
      .optionallyWith(
        secretOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.secretOptions)
      .build()
  }
  def asReadOnly: zio.aws.batch.model.LogConfiguration.ReadOnly =
    zio.aws.batch.model.LogConfiguration.wrap(buildAwsValue())
}
object LogConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.LogConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.LogConfiguration =
      zio.aws.batch.model.LogConfiguration(
        logDriver,
        options.map(value => value),
        secretOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def logDriver: zio.aws.batch.model.LogDriver
    def options: Optional[Map[String, String]]
    def secretOptions: Optional[List[zio.aws.batch.model.Secret.ReadOnly]]
    def getLogDriver: ZIO[Any, Nothing, zio.aws.batch.model.LogDriver] =
      ZIO.succeed(logDriver)
    def getOptions: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("options", options)
    def getSecretOptions
        : ZIO[Any, AwsError, List[zio.aws.batch.model.Secret.ReadOnly]] =
      AwsError.unwrapOptionField("secretOptions", secretOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.LogConfiguration
  ) extends zio.aws.batch.model.LogConfiguration.ReadOnly {
    override val logDriver: zio.aws.batch.model.LogDriver =
      zio.aws.batch.model.LogDriver.wrap(impl.logDriver())
    override val options: Optional[Map[String, String]] = zio.aws.core.internal
      .optionalFromNullable(impl.options())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val secretOptions
        : Optional[List[zio.aws.batch.model.Secret.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.secretOptions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.batch.model.Secret.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.LogConfiguration
  ): zio.aws.batch.model.LogConfiguration.ReadOnly = new Wrapper(impl)
}
